@@ -1,4 +1,4 @@
 from .kraken_extract_from_html import kraken_extract_from_html
 
 
-import extractors
+from .extractors import *
