@@ -1,7 +1,7 @@
 
 
 
-from ioc_finder import find_iocs
+#from ioc_finder import find_iocs
 
 
 def get(url, html):
@@ -11,7 +11,8 @@ def get(url, html):
 
 def extract_iocs(url, html):
 
-
+    a=1 
+    '''
     iocs = find_iocs(html)
 
     schemas = []
@@ -21,3 +22,4 @@ def extract_iocs(url, html):
 
     return schemas
 
+    '''
\ No newline at end of file
